@@ -22,7 +22,7 @@ biv_comp_subfunction<-function(df, benchmark, data = TRUE, corrtype="r",plot_tit
                                breaks=breaks, colors=NULL, remove_nas="pairwise", nboots=0,
                                parallel = FALSE,adjustment_weighting="raking", 
                                adjustment_vars=NULL,raking_targets=NULL,post_targets=NULL,
-                               boot_all=FALSE,percentile_ci=TRUE) {
+                               boot_all=FALSE,percentile_ci=TRUE,number=i) {
 
 
   ### Build title
@@ -205,7 +205,6 @@ biv_comp_subfunction<-function(df, benchmark, data = TRUE, corrtype="r",plot_tit
   fischer_cor_bench<- suppressWarnings(psych::fisherz(cor_matrix_bench$r))
   
   
-  
   fischer_z_test<-suppressWarnings(psych::paired.r(cor_matrix_df$r,cor_matrix_bench$r,n=cor_matrix_df$n, n2=cor_matrix_bench$n))
   fischer_z_test$p[round(cor_matrix_df$r,digits=3) %in%"-1" & round(cor_matrix_bench$r,digits=3) %in% "-1"]<-1
   fischer_z_test$p[fischer_z_test$p=="NaN"]<-NA
@@ -509,17 +508,15 @@ biv_comp_subfunction<-function(df, benchmark, data = TRUE, corrtype="r",plot_tit
 #' @examples
 #' 
 #' ## Get Data for comparison
-#' require(wooldridge)
-#' card<-wooldridge::card
 #' 
-#' south <- card[card$south==1,]
+#' data("card")
+#' 
 #' north <- card[card$south==0,]
-#' black <- card[card$black==1,]
 #' white <- card[card$black==0,]
 #' 
 #' ## use the function to plot the data 
 #' bivar_comp<-sampcompR::biv_compare(dfs = c("north","white"),
-#'                                    benchmarks = c("south","black"),
+#'                                    benchmarks = c("card","card"),
 #'                                    variables= c("age","educ","fatheduc","motheduc","wage","IQ"),
 #'                                    data=FALSE)
 #' bivar_comp
@@ -626,7 +623,7 @@ biv_compare<-function (dfs, benchmarks, variables=NULL, corrtype="r", data = TRU
                                adjustment_vars=adjustment_vars[[i]],
                                raking_targets=raking_targets[[i]],
                                post_targets=post_targets[[i]],boot_all=boot_all,
-                               percentile_ci=percentile_ci)
+                               percentile_ci=percentile_ci,number=i)
     message(paste("survey",i,"of",length(dfs),"is compared"))
     
     #return(help[[i]])###
@@ -930,8 +927,8 @@ biv_compare<-function (dfs, benchmarks, variables=NULL, corrtype="r", data = TRU
 # #' @examples
 # #' 
 # #' ## Get Data for comparison
-# #' require(wooldridge)
-# #' card<-wooldridge::card
+# #' 
+# #' data("card")
 # #' 
 # #' south <- card[card$south==1,]
 # #' north <- card[card$south==0,]
@@ -1609,7 +1606,7 @@ wgt_cor<-function(df, row, col, i = NULL, weight_var = NULL, stratas = NULL, ids
     
     
     
-    if(isFALSE(boot_all)) p_diff<-furrr::future_map(1:length(boot_r),~boot_pvalues(boot_r[[.x]],r=bench_cor[.x],benchmark=benchmark,percentile_ci=percentile_ci,r1=r[.x],r1_bench=r_bench[.x]))
+    if(isFALSE(boot_all)) p_diff<-furrr::future_map(1:length(boot_r),~boot_pvalues(boot_r[[.x]],r=bench_cor[.x],benchmark=benchmark,percentile_ci=percentile_ci,r1=r[.x],r1_bench=bench_cor[.x]))
     if(isTRUE(boot_all)) p_diff<-furrr::future_map(1:length(boot_r),~boot_pvalues(boot_r[[.x]],r=boot_r_bench[[.x]],benchmark=benchmark,percentile_ci=percentile_ci, r1=as.numeric(r[.x]), r1_bench=as.numeric(r_bench[.x])))
     
     
